==> haskell-gtk2hs-buildtools-0.13.2.1-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-gtk2hs-buildtools.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: gtk2hs-buildtools
version: 0.13.2.1
id: gtk2hs-buildtools-0.13.2.1-LrTlvh2PGwD9avYLf613kY
key: gtk2hs-buildtools-0.13.2.1-LrTlvh2PGwD9avYLf613kY
license: GPL-2
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-devel@lists.sourceforge.net
stability: stable
homepage: http://projects.haskell.org/gtk2hs/
synopsis: Tools to build the Gtk2Hs suite of User Interface libraries.
description:
    This package provides a set of helper programs necessary to
    build the Gtk2Hs suite of libraries. These tools include
    a modified c2hs binding tool that is used to generate
    FFI declarations, a tool to build a type hierarchy that
    mirrors the C type hierarchy of GObjects found in glib,
    and a generator for signal declarations that are used
    to call back from C to Haskell. These tools are not needed
    to actually run Gtk2Hs programs.
category: Development
author: Axel Simon, Duncan Coutts, Manuel Chakravaty
exposed: True
exposed-modules:
    Gtk2HsSetup TypeGen HookGenerator Gtk2HsC2Hs
hidden-modules: Paths_gtk2hs_buildtools BaseVersion Config Errors
                Binary DLists FastMutInt FileOps FNameOps Map Position Set UNames
                CIO State StateBase StateTrans Attributes Idents NameSpaces Lexers
                C CAST CAttrs CBuiltin CLexer CNames CParser CParserMonad CPretty
                CTokens CTrav CHS CHSLexer CInfo GBMonad GenBind GenHeader
                C2HSState Switches C2HSConfig Version
abi: c16020c129bd78f4b2c0efedd96f5d4e
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/gtk2hs-buildtools-0.13.2.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/gtk2hs-buildtools-0.13.2.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/gtk2hs-buildtools-0.13.2.1
hs-libraries: HSgtk2hs-buildtools-0.13.2.1-LrTlvh2PGwD9avYLf613kY
depends:
    Cabal-1.24.0.0 array-0.5.1.1 base-4.9.0.0 containers-0.5.7.1
    directory-1.2.6.2 filepath-1.4.1.0
    hashtables-1.2.1.0-AaXmM36fMlN6f2RbFgLszy pretty-1.1.3.3
    process-1.4.2.0 random-1.1-54KmMHXjttlERYcr1mvsAe
haddock-interfaces: /usr/share/doc/haskell-gtk2hs-buildtools/html/gtk2hs-buildtools.haddock
haddock-html: /usr/share/doc/haskell-gtk2hs-buildtools/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-gtk2hs-buildtools-0.13.2.2-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-gtk2hs-buildtools.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: gtk2hs-buildtools
version: 0.13.2.2
id: gtk2hs-buildtools-0.13.2.2-Ed4M7ddejPfDg07m395LiC
key: gtk2hs-buildtools-0.13.2.2-Ed4M7ddejPfDg07m395LiC
license: GPL-2
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-devel@lists.sourceforge.net
stability: stable
homepage: http://projects.haskell.org/gtk2hs/
synopsis: Tools to build the Gtk2Hs suite of User Interface libraries.
description:
    This package provides a set of helper programs necessary to
    build the Gtk2Hs suite of libraries. These tools include
    a modified c2hs binding tool that is used to generate
    FFI declarations, a tool to build a type hierarchy that
    mirrors the C type hierarchy of GObjects found in glib,
    and a generator for signal declarations that are used
    to call back from C to Haskell. These tools are not needed
    to actually run Gtk2Hs programs.
category: Development
author: Axel Simon, Duncan Coutts, Manuel Chakravaty
exposed: True
exposed-modules:
    Gtk2HsSetup TypeGen HookGenerator Gtk2HsC2Hs
hidden-modules: Paths_gtk2hs_buildtools BaseVersion Config Errors
                Binary DLists FastMutInt FileOps FNameOps Map Position Set UNames
                CIO State StateBase StateTrans Attributes Idents NameSpaces Lexers
                C CAST CAttrs CBuiltin CLexer CNames CParser CParserMonad CPretty
                CTokens CTrav CHS CHSLexer CInfo GBMonad GenBind GenHeader
                C2HSState Switches C2HSConfig Version
abi: ba7bb998e3be9532373b7f8f9738c3a1
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/gtk2hs-buildtools-0.13.2.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/gtk2hs-buildtools-0.13.2.2
data-dir: /usr/share/i386-linux-ghc-8.0.1/gtk2hs-buildtools-0.13.2.2
hs-libraries: HSgtk2hs-buildtools-0.13.2.2-Ed4M7ddejPfDg07m395LiC
depends:
    Cabal-1.24.0.0 array-0.5.1.1 base-4.9.0.0 containers-0.5.7.1
    directory-1.2.6.2 filepath-1.4.1.0
    hashtables-1.2.1.0-KpD1dORkz4bFlaOoTGiVHI pretty-1.1.3.3
    process-1.4.2.0 random-1.1-54KmMHXjttlERYcr1mvsAe
haddock-interfaces: /usr/share/doc/haskell-gtk2hs-buildtools/html/gtk2hs-buildtools.haddock
haddock-html: /usr/share/doc/haskell-gtk2hs-buildtools/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
